/*______________________________________________________________________

	help.h - Help Window Manager Interface.
	
	Copyright  1988, 1989, 1990, Northwestern University.
_____________________________________________________________________*/


#ifndef __help__
#define __help__

extern void help_Open (short tag);

/* Tags for help system */

#define	tagFirstButton	300		/* first button - the other buttons
									are assigned tags 301 through 309 */
#define	tagUpperRight	320		/* upper right corner of main window */
#define	tagReport		321		/* report rectangle */
#define	tagMainWind		500		/* main window */
#define	tagHelpWind		501		/* help window */
#define	tagHelpTcon		603		/* help window table of contents */
#define	tagPrefBeep		330		/* prefs beep option */
#define	tagPrefStation	331		/* prefs scanning station option */
#define	tagPrefSave		332		/* prefs saved text file options */
#define	tagPrefNotif	333		/* prefs notification options */
#define	tagAbouWind		503		/* about window */
#define	tagCmdBase		600		/* base for menu commands */
#define	tagCmdMult		20		/* multiplier for menu commands */

#define	firstDocID			200		/* first doc STR# rsrc */
#define	tconID				128		/* TCON resource id */
#define	tagID				128		/* TAG resource id */
#define	cellID				128		/* CELL resource id */
#define	lDefID				128		/* LDEF for report module */


typedef enum WindKind {
	mainWind,				/* main window */
	helpWind,				/* help window */
	prefWind,				/* prefs window */
	abouWind,				/* about window */
	daWind,					/* da window */
} WindKind;

typedef enum EditCmd {
	undoCmd,
	editDummyCmd,	/* the separator line in the Edit menu */
	cutCmd,
	copyCmd,
	pasteCmd,
	clearCmd 
} EditCmd;


typedef void (*FUpdate)(void);
typedef void (*FActivate)(void);
typedef void (*FDeactivate)(void);
typedef void (*FResume)(void);
typedef void (*FSuspend)(void);
typedef void (*FClick)(Point where, short modifiers);
typedef void (*FHelp)(Point where);
typedef void (*FGrow)(short height, short width);
typedef void (*FZoom)(void);
typedef void (*FKey)(short key, short modifiers);
typedef void (*FClose)(void);
typedef void (*FDisk)(long message);
typedef Boolean (*FSave)(void);
typedef OSErr (*FPageSetup)(void);
typedef OSErr (*FPrint)(Boolean printOne);
typedef void (*FEdit)(EditCmd cmd);
typedef void (*FAdjust)(void);
typedef void (*FPeriodic)(void);
typedef Boolean (*FDialogPre)(short key);
typedef void (*FDialogPost)(short item);

typedef struct WindowObject {
	WindKind			windKind;			/* which kind of window */
	Rect				sizeRect;			/* size rectangle */
	FUpdate				update;				/* ptr to update function */
	FActivate			activate;			/* ptr to activate function */
	FDeactivate			deactivate;			/* ptr to deactivate function */
	FResume				resume;				/* ptr to resume function */
	FSuspend			suspend;			/* ptr to suspend function */
	FClick				click;				/* ptr to click function */
	FHelp				help;				/* ptr to help function */
	FGrow				grow;				/* ptr to grow function */
	FZoom				zoom;				/* ptr to zoom function */
	FKey				key;				/* ptr to key function */
	FClose				close;				/* ptr to close function */
	FDisk				disk;				/* ptr to disk inserted function */
	FSave				save;				/* ptr to save function */
	FPageSetup			pageSetup;			/* ptr to page setup function */
	FPrint				print;				/* ptr to print function */
	FEdit				edit;				/* ptr to edit function */
	FAdjust				adjust;				/* ptr to menu adjust function */
	FPeriodic			periodic;			/* ptr to periodic function */
	FDialogPre			dialogPre;			/* ptr to dialog event preprocessor */
	FDialogPost			dialogPost;			/* ptr to dialog event postprocessor */
} WindowObject;

#endif

